@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2001 Free Software Foundation, Inc.
+ * Copyright (C) 1999-2001, 2016 Free Software Foundation, Inc.
  * This file is part of the GNU LIBICONV Library.
  *
  * The GNU LIBICONV Library is free software; you can redistribute it
@@ -49,7 +49,7 @@ static const unsigned short cp775_2uni[128] = {
 };
 
 static int
-cp775_mbtowc (conv_t conv, ucs4_t *pwc, const unsigned char *s, int n)
+cp775_mbtowc (conv_t conv, ucs4_t *pwc, const unsigned char *s, size_t n)
 {
   unsigned char c = *s;
   if (c < 0x80)
@@ -118,7 +118,7 @@ static const unsigned char cp775_page25[168] = {
 };
 
 static int
-cp775_wctomb (conv_t conv, unsigned char *r, ucs4_t wc, int n)
+cp775_wctomb (conv_t conv, unsigned char *r, ucs4_t wc, size_t n)
 {
   unsigned char c = 0;
   if (wc < 0x0080) {
