@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2002 Free Software Foundation, Inc.
+ * Copyright (C) 1999-2002, 2016 Free Software Foundation, Inc.
  * This file is part of the GNU LIBICONV Library.
  *
  * The GNU LIBICONV Library is free software; you can redistribute it
@@ -25,7 +25,7 @@
  */
 
 static int
-java_mbtowc (conv_t conv, ucs4_t *pwc, const unsigned char *s, int n)
+java_mbtowc (conv_t conv, ucs4_t *pwc, const unsigned char *s, size_t n)
 {
   unsigned char c;
   ucs4_t wc, wc2;
@@ -94,7 +94,7 @@ simply_backslash:
 }
 
 static int
-java_wctomb (conv_t conv, unsigned char *r, ucs4_t wc, int n)
+java_wctomb (conv_t conv, unsigned char *r, ucs4_t wc, size_t n)
 {
   if (wc < 0x80) {
     *r = wc;
